@@ -1,3 +1,68 @@
+#' Produce a composite serie from multiple charcoal records using a local
+#' regression procedure (from the locfit package)
+#' 
+#' Produces a composite series from multiple charcoal records by using a robust
+#' locally weighted scatterplot smoother (LOWESS). The robust LOWESS uses the
+#' locfit function from the locfit package and is applied repeatedly (nboot
+#' times) on bootstrapped charcoal sites samples. The records charcoal values
+#' are pre-binned prior to sites resampling. This procedure is equivalent to
+#' Daniau et al. (2012).
+#' 
+#' 
+#' @param TR An object returned by \code{\link[paleofire]{pfTransform}}
+#' @param tarAge Numeric, the target ages for prebinning given in years (e.g.
+#' tarAge = seq(0, 10000, 20)). If unspecified the sequence is defined as
+#' tarAge=seq(from=min age, to=max Age, by=median resolution).
+#' @param binhw Numeric, bin half width for the prebinning procedure (use the
+#' same value as tarAge intervals for overlapping bins or tarAge intervals/2
+#' for non-overlapping bins).
+#' @param nboot Numeric, a number specifying the number of bootstrap
+#' replicates.
+#' @param hw Numeric, the half window width for the locfit procedure (in
+#' years).
+#' @param conf Numeric, define confidence levels.
+#' @param pseudodata Logical, if TRUE 10 percent of the data is reflected at
+#' the top and the bottom of the resampled serie prior of each locfit
+#' regression in order to correct for the edge effect introduced by the local
+#' regression, see Cowling & Hall (1996). Equivalent to "minimum slope"
+#' correction in Mann(2004).
+#' @param verbose Logical: verbose or not...
+#' @return
+#' 
+#' \item{out}{A "pfCompositeLF" object.}
+#' @author O.Blarquez
+#' @references Daniau, A. L., P. J. Bartlein, S. P. Harrison, I. C. Prentice,
+#' S. Brewer, P. Friedlingstein, T. I. Harrison-Prentice, J. Inoue, K. Izumi,
+#' J. R. Marlon, S. Mooney, M. J. Power, J. Stevenson, W. Tinner, Andri, M., J.
+#' Atanassova, H. Behling, M. Black, O. Blarquez, K. J. Brown, C. Carcaillet,
+#' E. A. Colhoun, D. Colombaroli, B. A. S. Davis, D. D'Costa, J. Dodson, L.
+#' Dupont, Z. Eshetu, D. G. Gavin, A. Genries, S. Haberle, D. J. Hallett, G.
+#' Hope, S. P. Horn, T. G. Kassa, F. Katamura, L. M. Kennedy, P. Kershaw, S.
+#' Krivonogov, C. Long, D. Magri, E. Marinova, G. M. McKenzie, P. I. Moreno, P.
+#' Moss, F. H. Neumann, E. Norstrom, C. Paitre, D. Rius, N. Roberts, G. S.
+#' Robinson, N. Sasaki, L. Scott, H. Takahara, V. Terwilliger, F. Thevenon, R.
+#' Turner, V. G. Valsecchi, B. Vanniere, M. Walsh, N. Williams, and Y. Zhang.
+#' 2012. Predictability of biomass burning in response to climate changes.
+#' Global Biogeochem. Cycles 26:GB4007. \cr \cr Cowling A, Hall P (1996) On
+#' pseudodata methods for removing boundary effects in kernel density
+#' estimation. Journal of the Royal Statistical Society, Series B 58(3):
+#' 551-563. \cr \cr Mann, M. E. (2004). On smoothing potentially non-stationary
+#' climate time series. Geophysical Research Letters, 31(7).
+#' @examples
+#' 
+#' ID=pfSiteSel(id_region=="WNA0", l12==1, long>=-160 & long<=-140)
+#' plot(ID, xlim=c(-180, -130), ylim=c(40,80))
+#' TR=pfTransform(ID, method=c("MinMax","Box-Cox","MinMax","Z-Score"),
+#'                BasePeriod=c(200,2000),QuantType="INFL")
+#' 
+#' COMP1=pfCompositeLF(TR, tarAge=seq(-50,4000,10), hw=200, nboot=100)
+#' 
+#' plot(COMP1)
+#' 
+#' ## Note: comparing confidence intervals based on 100 replicates is not recommended
+#' # (100 is used to decrease analysis time)
+#' 
+#' 
 pfCompositeLF=function(TR,hw=250,
                        tarAge=NULL,binhw=NULL,
                        nboot=1000,conf=c(0.05,0.95),
@@ -136,6 +201,7 @@ pfCompositeLF=function(TR,hw=250,
   
   bootci=t(apply(mboot, 1, quantile, probs = conf,  na.rm = TRUE))
   bootmean=t(apply(mboot, 1, mean,  na.rm = TRUE))
+  bootmed=t(apply(mboot, 1, median,  na.rm = TRUE))
   
   ## Locfit of all stacked data
   rm(x,y,dat)
@@ -186,6 +252,7 @@ pfCompositeLF=function(TR,hw=250,
                         halfwidth=hw,
                         conf=conf,
                         locfitAll=locfitAll,
+                        BootMed=structure(bootmed,row.names = as.character(centres),col.names=c("Median"),class = "matrix"), 
                         BootMean=structure(bootmean,row.names = as.character(centres),col.names=c("Mean"),class = "matrix"), 
                         BootCi=structure(bootci,row.names = as.character(centres),class = "matrix") ))
   class(output)="pfCompositeLF"
@@ -199,8 +266,50 @@ pfCompositeLF=function(TR,hw=250,
 
 ######PLOT########
 
+
+
+
+
+#' plot.pfCompositeLF
+#' 
+#' Plot pfCompositeLF object
+#' 
+#' @export
+#' @method plot pfCompositeLF
+#' @param x A "pfCompositeLF" object.
+#' @param type Character, type of plot among "ci", "prctile", "density"
+#' @param add Character, add=NULL by default, add="sitenum" could be specified
+#' to plot the sites number in eah bin along with the composite curve.
+#' @param conf Numeric, confidence levels.
+#' @param palette Character, color palette used with type=c("prctile",
+#' "density") among "jet" and "BW".
+#' @param xlim Numeric, x axis limits.
+#' @param ylim Numeric, y axis limits.
+#' @param main Character, title of the plot.
+#' @param text Logical, text options.
+#' @param what Character, indicates which transformed charcoal trend is used
+#' for the plot (type="ci"), default "locfit" indicates that the trend is the
+#' locfit applied to All binned data, use "mean" or "median" to plot the mean
+#' or median of the locfit relplicates given by the bootstrap procedure.
+#' @param \dots \dots{}
+#' @author O. Blarquez
+#' @examples
+#' 
+#' ID=pfSiteSel(id_region=="WNA0",l12==1,long>=-160,long<=-140)
+#' 
+#' TR=pfTransform(ID, method=c("MinMax","Box-Cox","MinMax","Z-Score"),
+#'                BasePeriod=c(200,2000),QuantType="INFL")
+#' 
+#' COMP1=pfCompositeLF(TR, tarAge=seq(-50,4000,10), hw=200, nboot=100)
+#' 
+#' plot(COMP1)
+#' 
+#' ## Note: comparing confidence intervals based on 100 replicates is not recommended
+#' # (100 is used to decrease analysis time)
+#' 
+#' 
 plot.pfCompositeLF=function(x,type="ci",add="NULL",conf=c(0.05,0.95),palette="jet",xlim=NULL,
-                            ylim=NULL,main="Composite",text=FALSE,...){
+                            ylim=NULL,main="Composite",text=FALSE,what="locfit",...){
   # Value for plotting:
   w=(x$BinCentres[2]-x$BinCentres[1])/2
   
@@ -208,8 +317,17 @@ plot.pfCompositeLF=function(x,type="ci",add="NULL",conf=c(0.05,0.95),palette="je
   if (type=="ci") bootci1=t(apply(x$mboot, 1, quantile, probs = conf,  na.rm = TRUE)) 
   if (type=="prctile") bootci1=t(apply(x$mboot, 1, quantile, probs = seq(0, 1, .01),  na.rm = TRUE))
   if(is.null(xlim)) xlim=c(max(x$BinCentres)+w,min(x$BinCentres)-w)
-  if(is.null(ylim)) {bootci1=t(apply(x$mboot, 1, quantile, probs = seq(0, 1, .01),  na.rm = TRUE))
-    ylim= c(min(bootci1,na.rm=T),max(bootci1,na.rm=T))}
+  if(is.null(ylim)) {
+    #bootci1=t(apply(x$mboot, 1, quantile, probs = seq(0, 1, .01),  na.rm = TRUE))
+    #ylim= c(min(bootci1,na.rm=T),max(bootci1,na.rm=T))
+    ylim= range( x$Result[,4:5])}
+  
+  # What to plot as the trend:
+  if (what=="mean") trend=x$BootMean
+  if (what=="median") trend=x$BootMed
+  if (what=="locfit") trend=x$locfitAll
+  
+  # Now plot:
   
   if (type=="ci"){
     
@@ -218,7 +336,7 @@ plot.pfCompositeLF=function(x,type="ci",add="NULL",conf=c(0.05,0.95),palette="je
     
     bootci1=t(apply(x$mboot, 1, quantile, probs = conf,  na.rm = TRUE))    
     
-    plot(x$BinCentres,x$BootMean, 
+    plot(x$BinCentres,trend, 
          xlim=xlim, ylim=ylim, axes=F, mgp=c(2,0,0),
          main=main, font.main=1, lab=c(8,5,5), 
          ylab="Composite", xlab="Age (cal yr BP)", cex.lab=1, pch=16, cex=0.5, type="l")
